Devtests
========

This folder contains tests that were created in the process of developing new features. They are left as illustrative usage examples; they are **not** maintained, and are not guaranteed to run with the current version of Starsim.